@@ -1,6 +1,6 @@
 """Test of data set functionalities"""
 import numpy as np
-from PyQt5 import QtWidgets
+import pytest
 
 import pyjibe.head
 
@@ -19,12 +19,9 @@ def test_clear_and_verify_data(qtbot):
     war = main_window.subwindows[0].widget()
     # clear data
     tpp = war.tab_preprocess
-    tpp.list_preproc_applied.clear()
     war.cb_autosave.setChecked(0)
     # perform simple filter
-    item = QtWidgets.QListWidgetItem()
-    item.setText("compute_tip_position")
-    tpp.list_preproc_applied.addItem(item)
+    tpp.set_preprocessing(["compute_tip_position"])
     # perform fitting with standard parameters
     # set initial parameters in user interface
     itab = war.tab_fit.table_parameters_initial
@@ -60,3 +57,25 @@ def test_fit_all(qtbot):
     a1 = war.data_set[0]
     a2 = war.data_set[1]
     assert a1.fit_properties == a2.fit_properties
+
+
+@pytest.mark.parametrize("method,contact_point", [
+    ["gradient_zero_crossing", 1895],
+    ["fit_constant_line", 1919],
+    ["deviation_from_baseline", 1908],
+    ])
+def test_preprocessing_poc_estimation(method, contact_point):
+    main_window = pyjibe.head.PyJibe()
+    main_window.load_data(files=make_directory_with_data(2))
+    war = main_window.subwindows[0].widget()
+    # clear data
+    war.cb_autosave.setChecked(0)
+    war.tabs.setCurrentIndex(0)
+    # perform simple filter
+    war.tab_preprocess.set_preprocessing(
+        preprocessing=["compute_tip_position", "correct_tip_offset"],
+        options={"correct_tip_offset": {"method": method}}
+    )
+    war.tabs.setCurrentIndex(1)
+    fd = war.data_set[0]
+    assert np.argmin(np.abs(fd["tip position"])) == contact_point
